
#ifndef __form_h
#define __form_h

/* Type of forms */
#define FORM_TYPE_STANDARD	1
#define FORM_TYPE_NAME_VALUE	2
#define FORM_TYPE_CHECK_LIST	3

#define	FORM_PNT		1
#define	FORM_SIZE		2
#define	FORM_TOP		3
#define	FORM_BOTTOM		4
#define	FORM_TOP_SCREEN		5
#define	FORM_BOTTOM_SCREEN	6
#define	FORM_WIDTH		7
#define	FORM_HEIGHT		8
#define	FORM_PREV_PNT		9
#define	FORM_HEADER_SIZE	10
#define	FORM_TYPE		11

#define FORM_NO_EMPHASIS	1
#define FORM_EMPHASIS		2

#define MAX_COLUMN		10

#define CHECK_MARK_ON 		"A"
#define CHECK_MARK_OFF       	"B"

typedef struct {
	int begin;	/* Beginning of column in term of characters */
	int end;	/* End of column in term of characters */
	int offset;	/* Allows a specific column to be offseted
				** vertically.  This allow a column to be
				** moved above or below the default line.
				** The number is in pixels,  if positive,
				** then the column is moved up.
				*/
} Column;

typedef struct {
	void (*SetValue)();	/* Function to call to set value Item	*/
	char * (*GetValue)();	/* Function to call to get value Item	*/
	char *name;	/* Name string				*/
} NVItem;

typedef struct {
	char *label1;	/* Label1 for title of form		*/
	char *label2;	/* Label2 for title of form		*/
	int value_len;	/* value field lenth			*/
	int name_len;	/* name field length			*/
	int NVnu;	/* Number of name value items		*/
	int update_col;	/* Column that may be changed by user 	*/
	int func_index;	/* index to next function being defined */
	char *str[5]; 	/* Prompt string			*/
	void (*func[5])(); /* Function to call			*/
	NVItem *nvitem;	/* List of all name items		*/
			/* Stored as a matrix			*/
} NV;

typedef struct {
	int		type;	/* type of form, Standard, Name Value */
	int		pnt;
	int		prev_pnt;
	int		size;
	int		header_size;
	int		top;
	int		bottom;
	int		top_screen;
	int		bottom_screen;
	void		(*draw_line)();
	void		(*draw_heading)();
	void		(*buttonpress)();
	int		pxinc;
	int		pyinc;
	int		x_offset;
	int		y_offset;
	int		line_width;	/* Max width of form */
	unsigned int	width;
	unsigned int	height;
	Window		win;
	Display		*disp;
	GC		gc;
	GC		rgc;
	XFontStruct 	*font_info;
	int		logo_height;
	int		ncol;
	Column		col[MAX_COLUMN];
	int		lock;
	NV		*nv;	/* Nave value pointer */
} Form;

/*************************************************
	GLOBAL PROTOTYPES: form.c
*************************************************/

void
OpenForm(
#if NeedFunctionPrototypes
	Form *form
#endif
);

void
CloseForm(
#if NeedFunctionPrototypes
	Form *form
#endif
);


void
InitForm(
#if NeedFunctionPrototypes
	Form *form,
	Display *disp,
	Window win,
	unsigned width,
	unsigned height,
	int logo_height,
	XFontStruct *font_info,
	GC gc,
	GC rgc,
	int num,
	int line_width,
	int ncol,
	void (*draw_heading)(),
	void (*draw_line)(),
	void (*buttonpress)()
#endif
);

void
HandleFormEvents(
#if NeedFunctionPrototypes
	XEvent *report
#endif
);


void
SetFormColumn(
#if NeedFunctionPrototypes
	Form *form,
	int col,
	int begin,
	int width
#endif
);

void
SetFormColOffset(
#if NeedFunctionPrototypes
	Form *form,
	int col,
	int offset
#endif
);

void
ResizeForm(
#if NeedFunctionPrototypes
	Form *form,
	unsigned width,
	unsigned height
#endif
);

void
FormNextLine(
#if NeedFunctionPrototypes
	Form *form
#endif
);

void
FormPreviousLine(
#if NeedFunctionPrototypes
	Form *form
#endif
);

void
SetForm(
#if NeedFunctionPrototypes
	Form *form,
	int name,
	int value
#endif
);

int
GetForm(
#if NeedFunctionPrototypes
	Form *form,
	int name
#endif
);

void
DrawFormString(
#if NeedFunctionPrototypes
	Form *form,
	int emphasis,
	char *str,
	int num,
	int col,
	int x_offset
#endif
);

void
DrawFormHeading(
#if NeedFunctionPrototypes
	Form *form,
	char *str,
	int line,
	int col
#endif
);

void
DrawForm(
#if NeedFunctionPrototypes
	Form *form
#endif
);

void
ExposeForm(
#if NeedFunctionPrototypes
	Form *form
#endif
);

void
FormHandleButtonPush(
#if NeedFunctionPrototypes
	Form *form,
	int x,
	int y
#endif
);

void
ClearForm(
#if NeedFunctionPrototypes
	Form *form
#endif
);

void
GetFormBottomLeft(
#if NeedFunctionPrototypes
	Form *form,
	int line,
	int col,
	int *x,
	int *y,
	unsigned *width,
	unsigned *height
#endif
);

int
GetFormColCenter(
#if NeedFunctionPrototypes
	Form *form,
	char *str,
	int col
#endif
);

void
DrawFormCheckMark(
#if NeedFunctionPrototypes
	Form *form,
	int n,
	int col,
	char *value
#endif
);

void
FormNV(
#if NeedFunctionPrototypes
	Form *form,
	unsigned int width,
	unsigned int height
#endif
);

void
InitFormNV(
#if NeedFunctionPrototypes
	Form *form,
	Display *disp,
	Window win,
	int logo_height,
	XFontStruct *font_info,
	GC gc,
	GC rgc,
	char *label1,
	char *label2,
	int value_len
#endif
);

void
SetFormNVItem(
#if NeedFunctionPrototypes
	Form *form,
	char *name,
	void (*SetValue)(),
	char * (*GetValue)()
#endif
);

void
NVDrawLine(
#if NeedFunctionPrototypes
	int n,
	int emphasis
#endif
);

#endif  /* End: __form_h */
